@@ -266,4 +266,15 @@ def draw_n_side_shape(num_sides:int, side_length:int, start_angle:int, start_at:
     else:
         for i in range(num_sides):
             turt.forward(side_length)
-            turt.left(angle)
\ No newline at end of file
+            turt.left(angle)
+
+
+
+def write_to_screen(write_at:tuple, text:str):
+    turt = Turtle()
+    turt.speed(0)
+    turt.penup()
+    turt.goto(write_at)
+    turt.write(text)
+    
+    pass
\ No newline at end of file
